@@ -27,11 +27,11 @@ def test_pubmedfetcher_ids():
         assert len(docs) == 4
         assert docs[0].identifier == "21886606"
         assert docs[1].identifier == "21886599"
-        assert docs[1].metadata["doi"] == "10.2174/157015911795017263"
+        assert docs[1].metadata["DOI"] == "10.2174/157015911795017263"
         assert docs[2].identifier == "10.18585/inabj.v12i2.1171"
-        assert docs[2].metadata["doi"] == "10.18585/inabj.v12i2.1171"
+        assert docs[2].metadata["DOI"] == "10.18585/inabj.v12i2.1171"
         assert docs[3].identifier == "21886588"
-        assert docs[3].metadata["pmc"] == "3137179"
+        assert docs[3].metadata["PMC"] == "3137179"
 
 
 @pytest.mark.skip(reason="Not a test")
